PCB Environment: IBox_3 Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Static Public Member Functions | Data Fields
IBox_3 Struct Reference

## Public Member Functions
constexpr | IBox_3 (const IPoint_3 &mn, const IPoint_3 &mx)
bool | nonzero () const
uint | w () const
uint | h () const
uint | d () const
int64_t | volume () const

## Static Public Member Functions
static constexpr const IBox_3 | EMPTY ()

## Data Fields
IPoint_3 | min
IPoint_3 | max

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Math/IPoint3.hpp